AccountView class abstract

Available extensions
Annotations
  • @freezed

Constructors

AccountView({@Default.new('com.atproto.admin.defs#accountView') String $type, required String did, required String handle, String? email, List<Map<String, dynamic>>? relatedRecords, @JsonKey.new(toJson: iso8601) required DateTime indexedAt, @InviteCodeConverter() InviteCode? invitedBy, @InviteCodeConverter() List<InviteCode>? invites, bool? invitesDisabled, @JsonKey.new(toJson: iso8601) DateTime? emailConfirmedAt, String? inviteNote, @JsonKey.new(toJson: iso8601) DateTime? deactivatedAt, @ThreatSignatureConverter() List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown})
const
factory
AccountView.fromJson(Map<String, Object?> json)
factory

Properties

$type → String
no setterinherited
$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $AccountViewCopyWith<AccountView>
Create a copy of AccountView with the given fields replaced by the non-null parameter values.
no setterinherited
deactivatedAt → DateTime?
no setterinherited
did → String
no setterinherited
email → String?
no setterinherited
emailConfirmedAt → DateTime?
no setterinherited
handle → String
no setterinherited
hasDeactivatedAt → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasEmail → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasEmailConfirmedAt → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasInvitedBy → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasInviteNote → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasNotDeactivatedAt → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasNotEmail → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasNotEmailConfirmedAt → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasNotInvitedBy → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
hasNotInviteNote → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
indexedAt → DateTime
no setterinherited
invitedBy → InviteCode?
no setterinherited
inviteNote → String?
no setterinherited
invites → List<InviteCode>?
no setterinherited
invitesDisabled → bool?
no setterinherited
isInvitesDisabled → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
isNotInvitesDisabled → bool

Available on AccountView, provided by the AccountViewExtension extension

no setter
relatedRecords → List<Map<String, dynamic>>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threatSignatures → List<ThreatSignature>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AccountView value)) → TResult

Available on AccountView, provided by the AccountViewPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AccountView value)?) → TResult?

Available on AccountView, provided by the AccountViewPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AccountView value)?, {required TResult orElse()}) → TResult

Available on AccountView, provided by the AccountViewPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String did, String handle, String? email, List<Map<String, dynamic>>? relatedRecords, DateTime indexedAt, InviteCode? invitedBy, List<InviteCode>? invites, bool? invitesDisabled, DateTime? emailConfirmedAt, String? inviteNote, DateTime? deactivatedAt, List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on AccountView, provided by the AccountViewPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AccountView to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String did, String handle, String? email, List<Map<String, dynamic>>? relatedRecords, DateTime indexedAt, InviteCode? invitedBy, List<InviteCode>? invites, bool? invitesDisabled, DateTime? emailConfirmedAt, String? inviteNote, DateTime? deactivatedAt, List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown)) → TResult

Available on AccountView, provided by the AccountViewPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String did, String handle, String? email, List<Map<String, dynamic>>? relatedRecords, DateTime indexedAt, InviteCode? invitedBy, List<InviteCode>? invites, bool? invitesDisabled, DateTime? emailConfirmedAt, String? inviteNote, DateTime? deactivatedAt, List<ThreatSignature>? threatSignatures, Map<String, dynamic>? $unknown)?) → TResult?

Available on AccountView, provided by the AccountViewPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) → bool

Constants

knownProps → const List<String>