AdminSendEmailOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

AdminSendEmailOutput({required bool sent, Map<String, dynamic>? $unknown})
const
factory
AdminSendEmailOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $AdminSendEmailOutputCopyWith<AdminSendEmailOutput>
Create a copy of AdminSendEmailOutput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isNotSent → bool

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputExtension extension

no setter
isSent → bool

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sent → bool
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AdminSendEmailOutput value)) → TResult

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AdminSendEmailOutput value)?) → TResult?

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AdminSendEmailOutput value)?, {required TResult orElse()}) → TResult

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool sent, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this AdminSendEmailOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool sent, Map<String, dynamic>? $unknown)) → TResult

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool sent, Map<String, dynamic>? $unknown)?) → TResult?

Available on AdminSendEmailOutput, provided by the AdminSendEmailOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>