LabelQueryLabelsOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

LabelQueryLabelsOutput({String? cursor, @LabelConverter() required List<Label> labels, Map<String, dynamic>? $unknown})
const
factory
LabelQueryLabelsOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
copyWith → $LabelQueryLabelsOutputCopyWith<LabelQueryLabelsOutput>
Create a copy of LabelQueryLabelsOutput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor → String?
no setterinherited
hasCursor → bool

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotCursor → bool

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputExtension extension

no setter
labels → List<Label>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LabelQueryLabelsOutput value)) → TResult

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LabelQueryLabelsOutput value)?) → TResult?

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LabelQueryLabelsOutput value)?, {required TResult orElse()}) → TResult

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cursor, List<Label> labels, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this LabelQueryLabelsOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cursor, List<Label> labels, Map<String, dynamic>? $unknown)) → TResult

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cursor, List<Label> labels, Map<String, dynamic>? $unknown)?) → TResult?

Available on LabelQueryLabelsOutput, provided by the LabelQueryLabelsOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>