RepoCreateRecordInput constructor
const
RepoCreateRecordInput({})
Implementation
@JsonSerializable(includeIfNull: false)
const factory RepoCreateRecordInput({
/// The handle or DID of the repo (aka, current account).
required String repo,
/// The NSID of the record collection.
required String collection,
/// The Record Key.
String? rkey,
/// Can be set to 'false' to skip Lexicon schema validation of record data, 'true' to require it, or leave unset to validate only for known Lexicons.
bool? validate,
required Map<String, dynamic> record,
/// Compare and swap with the previous commit by CID.
String? swapCommit,
Map<String, dynamic>? $unknown,
}) = _RepoCreateRecordInput;