ServerCreateAccountOutput class abstract

Available extensions
Annotations
  • @freezed

Constructors

ServerCreateAccountOutput({required String accessJwt, required String refreshJwt, required String handle, required String did, Map<String, dynamic>? didDoc, Map<String, dynamic>? $unknown})
const
factory
ServerCreateAccountOutput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown → Map<String, dynamic>?
no setterinherited
accessJwt → String
no setterinherited
copyWith → $ServerCreateAccountOutputCopyWith<ServerCreateAccountOutput>
Create a copy of ServerCreateAccountOutput with the given fields replaced by the non-null parameter values.
no setterinherited
did → String
The DID of the new account.
no setterinherited
didDoc → Map<String, dynamic>?
no setterinherited
handle → String
no setterinherited
hasDidDoc → bool

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
hasNotDidDoc → bool

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputExtension extension

no setter
refreshJwt → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ServerCreateAccountOutput value)) → TResult

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ServerCreateAccountOutput value)?) → TResult?

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ServerCreateAccountOutput value)?, {required TResult orElse()}) → TResult

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String accessJwt, String refreshJwt, String handle, String did, Map<String, dynamic>? didDoc, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this ServerCreateAccountOutput to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String accessJwt, String refreshJwt, String handle, String did, Map<String, dynamic>? didDoc, Map<String, dynamic>? $unknown)) → TResult

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String accessJwt, String refreshJwt, String handle, String did, Map<String, dynamic>? didDoc, Map<String, dynamic>? $unknown)?) → TResult?

Available on ServerCreateAccountOutput, provided by the ServerCreateAccountOutputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

knownProps → const List<String>