ServerDeactivateAccountInput constructor

const ServerDeactivateAccountInput({
  1. @JsonKey.new(toJson: iso8601) DateTime? deleteAfter,
  2. Map<String, dynamic>? $unknown,
})

Implementation

@JsonSerializable(includeIfNull: false)
const factory ServerDeactivateAccountInput({
  /// A recommendation to server as to how long they should hold onto the deactivated account before deleting.
  @JsonKey(toJson: iso8601) DateTime? deleteAfter,

  Map<String, dynamic>? $unknown,
}) = _ServerDeactivateAccountInput;