deleteAfter property
A recommendation to server as to how long they should hold onto the deactivated account before deleting.
Implementation
@JsonKey(toJson: iso8601) DateTime? get deleteAfter;
A recommendation to server as to how long they should hold onto the deactivated account before deleting.
@JsonKey(toJson: iso8601) DateTime? get deleteAfter;