ServerGetSessionStatus class sealed

Available extensions
Annotations
  • @freezed

Constructors

ServerGetSessionStatus.knownValue({required KnownServerGetSessionStatus data})
const
factory
ServerGetSessionStatus.unknown({required String data})
const
factory

Properties

data → Object
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isKnownValue → bool

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusExtension extension

no setter
isNotKnownValue → bool

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusExtension extension

no setter
isNotUnknown → bool

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusExtension extension

no setter
isUnknown → bool

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusExtension extension

no setter
knownValue → KnownServerGetSessionStatus?

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → String?

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusExtension extension

no setter

Methods

map<TResult extends Object?>({required TResult knownValue(ServerGetSessionStatusKnownValue value), required TResult unknown(ServerGetSessionStatusUnknown value)}) → TResult

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? knownValue(ServerGetSessionStatusKnownValue value)?, TResult? unknown(ServerGetSessionStatusUnknown value)?}) → TResult?

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult knownValue(ServerGetSessionStatusKnownValue value)?, TResult unknown(ServerGetSessionStatusUnknown value)?, required TResult orElse()}) → TResult

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult knownValue(KnownServerGetSessionStatus data)?, TResult unknown(String data)?, required TResult orElse()}) → TResult

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult knownValue(KnownServerGetSessionStatus data), required TResult unknown(String data)}) → TResult

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? knownValue(KnownServerGetSessionStatus data)?, TResult? unknown(String data)?}) → TResult?

Available on ServerGetSessionStatus, provided by the ServerGetSessionStatusPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(String? value) → ServerGetSessionStatus?