LexiconService class base

com.atproto.lexicon.*

Constructors

LexiconService(ServiceContext ctx)

Properties

ctx → ServiceContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → LexiconSchemaRecordAccessor
Representation of Lexicon schemas themselves, when published as atproto records. Note that the schema language is not defined in Lexicon; this meta schema currently only includes a single version field ('lexicon'). See the atproto specifications for description of the other expected top-level fields ('id', 'defs', etc).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveLexicon({required String nsid, String? $service, Map<String, String>? $headers, Map<String, String>? $unknown}) → Future<XRPCResponse<LexiconResolveLexiconOutput>>
Resolves an atproto lexicon (NSID) to a schema.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited