SyncGetHostStatusOutput constructor
const
SyncGetHostStatusOutput({
- required String hostname,
- int? seq,
- int? accountCount,
- @HostStatusConverter() HostStatus? status,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory SyncGetHostStatusOutput({
required String hostname,
/// Recent repo stream event sequence number. May be delayed from actual stream processing (eg, persisted cursor not in-memory cursor).
int? seq,
/// Number of accounts on the server which are associated with the upstream host. Note that the upstream may actually have more accounts.
int? accountCount,
@HostStatusConverter() HostStatus? status,
Map<String, dynamic>? $unknown,
}) = _SyncGetHostStatusOutput;