Account constructor
const
Account({
- @Default.new('com.atproto.sync.subscribeRepos#account') String $type,
- required int seq,
- required String did,
- required DateTime time,
- required bool active,
- @AccountStatusConverter() AccountStatus? status,
- Map<
String, dynamic> ? $unknown,
Implementation
@JsonSerializable(includeIfNull: false)
const factory Account({
@Default('com.atproto.sync.subscribeRepos#account') String $type,
required int seq,
required String did,
required DateTime time,
/// Indicates that the account has a repository which can be fetched from the host that emitted this event.
required bool active,
/// If active=false, this optional field indicates a reason for why the account is not active.
@AccountStatusConverter() AccountStatus? status,
Map<String, dynamic>? $unknown,
}) = _Account;