MessageMe class abstract

Available extensions
Annotations
  • @freezed

Constructors

MessageMe({@Default.new('com.germnetwork.declaration#messageMe') String $type, required String messageMeUrl, @MessageMeShowButtonToConverter() required MessageMeShowButtonTo showButtonTo, Map<String, dynamic>? $unknown})
const
factory
MessageMe.fromJson(Map<String, Object?> json)
factory

Properties

$type String
no setterinherited
$unknown Map<String, dynamic>?
no setterinherited
copyWith → $MessageMeCopyWith<MessageMe>
Create a copy of MessageMe with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
messageMeUrl String
A URL to present to an account that does not have its own com.germnetwork.declaration record, must have an empty fragment component, where the app should fill in the fragment component with the DIDs of the two accounts who wish to message each other
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showButtonTo MessageMeShowButtonTo
The policy of who can message the account, this value is included in the keyPackage, but is duplicated here to allow applications to decide if they should show a 'Message on Germ' button to the viewer.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_MessageMe value)) → TResult

Available on MessageMe, provided by the MessageMePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_MessageMe value)?) → TResult?

Available on MessageMe, provided by the MessageMePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_MessageMe value)?, {required TResult orElse()}) → TResult

Available on MessageMe, provided by the MessageMePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String messageMeUrl, MessageMeShowButtonTo showButtonTo, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on MessageMe, provided by the MessageMePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this MessageMe to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String $type, String messageMeUrl, MessageMeShowButtonTo showButtonTo, Map<String, dynamic>? $unknown)) → TResult

Available on MessageMe, provided by the MessageMePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String messageMeUrl, MessageMeShowButtonTo showButtonTo, Map<String, dynamic>? $unknown)?) → TResult?

Available on MessageMe, provided by the MessageMePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validate(Map<String, dynamic> object) bool

Constants

knownProps → const List<String>