showButtonTo property
The policy of who can message the account, this value is included in the keyPackage, but is duplicated here to allow applications to decide if they should show a 'Message on Germ' button to the viewer.
Implementation
String get messageMeUrl;/// The policy of who can message the account, this value is included in the keyPackage, but is duplicated here to allow applications to decide if they should show a 'Message on Germ' button to the viewer.
@MessageMeShowButtonToConverter() MessageMeShowButtonTo get showButtonTo;