DeclarationService class base
com.germnetwork.declaration.*
Constructors
Properties
- ctx → ServiceContext
-
final
- declaration → DeclarationRecordAccessor
-
A declaration of a Germ Network account
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited