AtUri class sealed
This is the Dart implementation of AT Uri in AT Protocol.
Grammar
- atp-url = "at://" authority path
"#" fragment - authority = reg-name / did
- path = [ "/" coll-nsid
"/" record-id] - coll-nsid = nsid
- record-id = 1*pchar
Constructors
- AtUri(String uri)
-
Returns the new instance of unparsed AT URI.
constfactory
- AtUri.make(String handleOrDid, [String? collection, String? rkey])
-
Returns the new instance of parsed AT URI based on
handleOrDid, andcollectionandrkeyas optionals.factory - AtUri.parse(String uri)
-
Returns the new instance of parsed AT URI.
factory
- AtUri.parseStrict(String uri)
-
Returns the new instance of parsed AT URI after validating
uriwithensureValidAtUri.factory
Properties
- collection → NSID
-
Returns the collection.
no setter
- collectionOrNull → NSID?
-
Returns the collection, or null if this AT URI does not have a
collection segment.
no setter
- hash → String
-
Returns the hash.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostname → String
-
Returns the hostname.
no setter
- href → String
-
Returns the href.
no setter
- origin → String
-
Returns the origin.
no setter
- pathname → String
-
Returns the pathname.
no setter
- protocol → String
-
Returns the protocol.
no setter
- rkey → String
-
Returns the rkey.
no setter
- rkeyOrNull → String?
-
Returns the rkey, or null if this AT URI does not have an rkey
segment.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → String
-
Returns the query string of this AT URI, without the leading
?.no setter -
searchParams
→ Map<
String, String> -
Returns the query parameters of this AT URI.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited