isNotRaw property
bool
get
isNotRaw
Returns true if this codec is not raw binary, otherwise false.
Implementation
bool get isNotRaw => !isRaw;
Returns true if this codec is not raw binary, otherwise false.
bool get isNotRaw => !isRaw;