isRaw property
bool
get
isRaw
Returns true if this codec is raw binary (0x55), otherwise false.
Implementation
bool get isRaw => code == 0x55;
Returns true if this codec is raw binary (0x55), otherwise false.
bool get isRaw => code == 0x55;