blocks property

Map<String, dynamic> get blocks
inherited

CAR file containing relevant blocks, as a diff since the previous repo state. The commit must be included as a block, and the commit block CID must be the first entry in the CAR header 'roots' list.

Implementation

@JsonKey(includeIfNull: true) String? get since;/// CAR file containing relevant blocks, as a diff since the previous repo state. The commit must be included as a block, and the commit block CID must be the first entry in the CAR header 'roots' list.
 Map<String, dynamic> get blocks;