since property

  1. @JsonKey.new(includeIfNull: true)
String? get since
inherited

The rev of the last emitted commit from this repo (if any).

Implementation

String get rev;/// The rev of the last emitted commit from this repo (if any).
@JsonKey(includeIfNull: true) String? get since;