FirehoseErrorException class final

Thrown when the relay sends a firehose error frame (op == -1), such as FutureCursor or ConsumerTooSlow.

Previously these frames were indistinguishable from an unknown message.

Implemented types

Constructors

FirehoseErrorException({required String error, String? message})
Returns the new instance of FirehoseErrorException.
const

Properties

error → String
The machine readable error name, e.g. FutureCursor.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The optional human readable message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited