menu
atproto package
documentation
firehose.dart
SyncSubscribeReposAdaptor class
SyncSubscribeReposAdaptor class
dark_mode
light_mode
SyncSubscribeReposAdaptor
class
final
Constructors
SyncSubscribeReposAdaptor
()
const
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
execute
(
dynamic
data
)
→
USyncSubscribeReposMessage
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
dynamic
data
)
→
Map
<
String
,
dynamic
>
Decodes a raw firehose frame into the JSON map form of a
com.atproto.sync.subscribeRepos
message, with the CAR
blocks
, the
ops
CID links, and the top-level
commit
/
prevData
CID links already normalized per the atproto data model.
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
atproto package
documentation
firehose
SyncSubscribeReposAdaptor class
firehose library