Generates DPoP key pairs and signs DPoP proof JWTs (RFC 9449). Inject a custom implementation to sign with a platform keystore / non-extractable key. The DPoPKeyPair strings are opaque to everyone but the signer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createProof(
{required String htm, required String htu, required DPoPKeyPair keyPair, String? nonce, String? accessToken}) → Future< String> -
Builds a signed
dpop+jwtproof.htuMUST already exclude query and fragment (RFC 9449 4.2). WhenaccessTokenis non-null anathclaim is included; whennonceis non-null anonceclaim is included. -
generateKeyPair(
) → Future< DPoPKeyPair> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited