refreshToken property
The refresh token for obtaining new access tokens.
Used in conjunction with DPoP proof for secure token refresh as specified in Section 5 of RFC 9449.
May be an empty string when the authorization server did not issue a refresh token.
Implementation
final String refreshToken;