DeclarationRecord class abstract
A declaration of a Germ Network account
- Available extensions
- Annotations
-
- @freezed
Constructors
-
DeclarationRecord({@Default.new('com.germnetwork.declaration') String $type, required String version, required Map<
String, dynamic> currentKey, @MessageMeConverter() MessageMe? messageMe, Map<String, dynamic> ? keyPackage, List<Map< ? continuityProofs, Map<String, dynamic> >String, dynamic> ? $unknown}) -
constfactory
-
DeclarationRecord.fromJson(Map<
String, Object?> json) -
factory
Properties
- $type → String
-
no setterinherited
-
$unknown
→ Map<
String, dynamic> ? -
no setterinherited
-
continuityProofs
→ List<
Map< ?String, dynamic> > -
no setterinherited
-
copyWith
→ $DeclarationRecordCopyWith<
DeclarationRecord> -
Create a copy of DeclarationRecord
with the given fields replaced by the non-null parameter values.
no setterinherited
-
currentKey
→ Map<
String, dynamic> -
Opaque value, an ed25519 public key prefixed with a byte enum
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasKeyPackage → bool
-
Available on DeclarationRecord, provided by the DeclarationRecordExtension extension
no setter - hasMessageMe → bool
-
Available on DeclarationRecord, provided by the DeclarationRecordExtension extension
no setter - hasNotKeyPackage → bool
-
Available on DeclarationRecord, provided by the DeclarationRecordExtension extension
no setter - hasNotMessageMe → bool
-
Available on DeclarationRecord, provided by the DeclarationRecordExtension extension
no setter -
keyPackage
→ Map<
String, dynamic> ? -
Opaque value, contains MLS KeyPackage(s), and other signature data, and is signed by the currentKey
no setterinherited
- messageMe → MessageMe?
-
Controls who can message this account
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
Semver version number, without pre-release or build information, for the format of opaque content
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_DeclarationRecord value)) → TResult -
Available on DeclarationRecord, provided by the DeclarationRecordPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_DeclarationRecord value)?) → TResult? -
Available on DeclarationRecord, provided by the DeclarationRecordPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_DeclarationRecord value)?, {required TResult orElse()}) → TResult -
Available on DeclarationRecord, provided by the DeclarationRecordPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String $type, String version, Map< String, dynamic> currentKey, MessageMe? messageMe, Map<String, dynamic> ? keyPackage, List<Map< ? continuityProofs, Map<String, dynamic> >String, dynamic> ? $unknown)?, {required TResult orElse()}) → TResult -
Available on DeclarationRecord, provided by the DeclarationRecordPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this DeclarationRecord to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String $type, String version, Map< String, dynamic> currentKey, MessageMe? messageMe, Map<String, dynamic> ? keyPackage, List<Map< ? continuityProofs, Map<String, dynamic> >String, dynamic> ? $unknown)) → TResult -
Available on DeclarationRecord, provided by the DeclarationRecordPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String $type, String version, Map< String, dynamic> currentKey, MessageMe? messageMe, Map<String, dynamic> ? keyPackage, List<Map< ? continuityProofs, Map<String, dynamic> >String, dynamic> ? $unknown)?) → TResult? -
Available on DeclarationRecord, provided by the DeclarationRecordPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
knownProps
→ const List<
String>