keyPackage property
Opaque value, contains MLS KeyPackage(s), and other signature data, and is signed by the currentKey
Implementation
@MessageMeConverter() MessageMe? get messageMe;/// Opaque value, contains MLS KeyPackage(s), and other signature data, and is signed by the currentKey
Map<String, dynamic>? get keyPackage;