ServiceContext class base
Constructors
-
ServiceContext({Map<
String, String> ? headers, Protocol? protocol, String? service, String? relayService, Session? session, OAuthSession? oAuthSession, Duration? timeout, RetryConfig? retryConfig, GetClient? getClient, PostClient? postClient, Future<Session> onRefreshSession(Session current)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
no setter
- oAuthSession → OAuthSession?
-
The current OAuth session.
final
-
onRefreshSession
→ Future<
Session> Function(Session current)? -
Optional callback used to refresh an expired session.
final
- relayService → String
-
The current relay service.
Defaults to
bsky.network.final - repo → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → String
-
The current service.
Defaults to
bsky.social.final - session → Session?
-
Returns the current session.
no setter
Methods
-
get<
T> (NSID methodId, {String? service, Map< String, String> ? headers, Map<String, dynamic> ? parameters, ResponseDataBuilder<T> ? to, ResponseDataAdaptor? adaptor, GetClient? client}) → Future<XRPCResponse< T> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post<
T> (NSID methodId, {String? service, Map< String, String> ? headers, Map<String, dynamic> ? parameters, dynamic body, ResponseDataBuilder<T> ? to, PostClient? client}) → Future<XRPCResponse< T> > -
stream<
T> (NSID methodId, {Map< String, dynamic> ? parameters, ResponseDataBuilder<T> ? to, ResponseDataAdaptor? adaptor}) → Future<XRPCResponse< Subscription< >T> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited