onRefreshSession property

Future<Session> Function(Session current)? onRefreshSession
final

Optional callback used to refresh an expired session.

Given the current session it must return a new session with fresh tokens. When null, expired access tokens are not refreshed automatically.

Implementation

final Future<Session> Function(Session current)? onRefreshSession;