firehose library
Exceptions / Errors
- FirehoseErrorException
-
Thrown when the relay sends a firehose error frame (
op == -1), such asFutureCursororConsumerTooSlow. - FirehoseFrameException
- Thrown when a firehose frame is malformed or arrives in an unexpected shape (e.g. a WebSocket text frame instead of the expected binary frame).