since property
The rev of the last emitted commit from this repo (if any).
Implementation
String get rev;/// The rev of the last emitted commit from this repo (if any).
@JsonKey(includeIfNull: true) String? get since;
The rev of the last emitted commit from this repo (if any).
String get rev;/// The rev of the last emitted commit from this repo (if any).
@JsonKey(includeIfNull: true) String? get since;