FirehoseFrameException class final

Thrown when a firehose frame is malformed or arrives in an unexpected shape (e.g. a WebSocket text frame instead of the expected binary frame).

Implemented types

Constructors

FirehoseFrameException(String message)
Returns the new instance of FirehoseFrameException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The human readable error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited